@@ -291,6 +291,9 @@ def extract_admin_areas(text, print_log=False):
     if print_log:
         print("input parts:", parts_by_space)
 
+    if len(parts_by_space) == 0:
+        return None, None, None, 0
+
     parts_by_space_by_lv1_native = lv1_native_vectorizer.transform(np.array(parts_by_space))
     cos_sim_parts_by_space_vs_lv1_native = cosine_similarity(parts_by_space_by_lv1_native, mtx_lv1_native)
     jw_sim_parts_by_space_vs_lv1_native = jaro_winkler_similarity(parts_by_space, lv1_areas["lv1_native"])
@@ -423,6 +426,9 @@ def extract_admin_areas(text, print_log=False):
         if print_log:
             print("input english parts:", parts_by_comma)
 
+        if len(parts_by_comma) == 0:
+            return None, None, None, 0
+
         parts_by_comma_by_lv1_en = lv1_en_vectorizer.transform(np.array(parts_by_comma))
         cos_sim_parts_by_comma_vs_lv1_en = cosine_similarity(parts_by_comma_by_lv1_en, mtx_lv1_en)
         jw_sim_parts_by_comma_vs_lv1_en = jaro_winkler_similarity(parts_by_comma, lv1_areas["lv1_en"])
